@@ -1167,7 +1167,7 @@ pluma_document_get_short_name_for_display (PlumaDocument *doc)
 /**
  * pluma_document_set_short_name_for_display:
  * @doc:
- * @short_name: (allow-none):
+ * @name: (allow-none):
  */
 void
 pluma_document_set_short_name_for_display (PlumaDocument *doc,
@@ -2113,7 +2113,7 @@ pluma_document_search_backward (PlumaDocument     *doc,
 								  search_flags,
 								  &m_start,
 								  &m_end,
-								  end,
+								  start,
 								  FALSE,
 								  &doc->priv->last_replace_text);
 		}
