@@ -491,69 +491,6 @@ pluma_documents_panel_class_init (PlumaDocumentsPanelClass *klass)
 	g_type_class_add_private (object_class, sizeof (PlumaDocumentsPanelPrivate));
 }
 
-static GtkTreePath *
-get_current_path (PlumaDocumentsPanel *panel)
-{
-	gint num;
-	GtkWidget *nb;
-	GtkTreePath *path;
-
-	nb = _pluma_window_get_notebook (panel->priv->window);
-	num = gtk_notebook_get_current_page (GTK_NOTEBOOK (nb));
-
-	path = gtk_tree_path_new_from_indices (num, -1);
-
-	return path;
-}
-
-static void
-menu_position (GtkMenu             *menu,
-	       gint                *x,
-	       gint                *y,
-	       gboolean            *push_in,
-	       PlumaDocumentsPanel *panel)
-{
-	GtkTreePath *path;
-	GdkRectangle rect;
-	gint wy;
-	GtkAllocation allocation;
-	GtkRequisition requisition;
-	GtkWidget *w;
-
-	w = panel->priv->treeview;
-
-	gtk_widget_get_allocation(w, &allocation);
-
-	path = get_current_path (panel);
-
-	gtk_tree_view_get_cell_area (GTK_TREE_VIEW (w),
-				     path,
-				     NULL,
-				     &rect);
-
-	wy = rect.y;
-
-	gdk_window_get_origin (gtk_widget_get_window (w), x, y);
-
-	gtk_widget_get_preferred_size (GTK_WIDGET (menu), NULL, &requisition);
-
-	if (gtk_widget_get_direction (w) == GTK_TEXT_DIR_RTL)
-	{
-		*x += allocation.x + allocation.width - requisition.width - 10;
-	}
-	else
-	{
-		*x += allocation.x + 10;
-	}
-
-	wy = MAX (*y + 5, *y + wy + 5);
-	wy = MIN (wy, *y + allocation.height - requisition.height - 5);
-	
-	*y = wy;
-
-	*push_in = TRUE;
-}
-
 static gboolean
 show_popup_menu (PlumaDocumentsPanel *panel,
 		 GdkEventButton      *event)
@@ -566,24 +503,11 @@ show_popup_menu (PlumaDocumentsPanel *panel,
 
 	if (event != NULL)
 	{
-		gtk_menu_popup (GTK_MENU (menu),
-				NULL,
-				NULL,
-				NULL,
-				NULL,
-				event->button,
-				event->time);
+		gtk_menu_popup_at_pointer (GTK_MENU (menu), NULL);
 	}
 	else
 	{
-		gtk_menu_popup (GTK_MENU (menu),
-				NULL,
-				NULL,
-				(GtkMenuPositionFunc) menu_position,
-				panel,
-				0,
-				gtk_get_current_event_time ());
-
+		menu_popup_at_treeview_selection (menu, panel->priv->treeview);
 		gtk_menu_shell_select_first (GTK_MENU_SHELL (menu), FALSE);
 	}
 
