@@ -107,6 +107,8 @@ static void	pluma_view_dispose		(GObject          *object);
 static void	pluma_view_finalize		(GObject          *object);
 static gint     pluma_view_focus_out		(GtkWidget        *widget,
 						 GdkEventFocus    *event);
+static gboolean pluma_view_scroll_event         (GtkWidget        *widget,
+                                                 GdkEventScroll   *event);
 static gboolean pluma_view_drag_motion		(GtkWidget        *widget,
 						 GdkDragContext   *context,
 						 gint              x,
@@ -181,6 +183,36 @@ document_read_only_notify_handler (PlumaDocument *document,
 				    !pluma_document_get_readonly (document));
 }
 
+static gboolean
+pluma_view_scroll_event (GtkWidget      *widget,
+                         GdkEventScroll *event)
+{
+	if (event->direction == GDK_SCROLL_UP)
+	{
+		event->delta_x = 0;
+		event->delta_y = -1;
+	}
+	else if (event->direction == GDK_SCROLL_DOWN)
+	{
+		event->delta_x = 0;
+		event->delta_y = 1;
+	}
+	else if (event->direction == GDK_SCROLL_LEFT)
+	{
+		event->delta_x = -1;
+		event->delta_y = 0;
+	}
+	else if (event->direction == GDK_SCROLL_RIGHT)
+	{
+		event->delta_x = 1;
+		event->delta_y = 0;
+	}
+
+	event->direction = GDK_SCROLL_SMOOTH;
+
+	return FALSE;
+}
+
 static void
 pluma_view_class_init (PlumaViewClass *klass)
 {
@@ -195,6 +227,7 @@ pluma_view_class_init (PlumaViewClass *klass)
 
 	widget_class->focus_out_event = pluma_view_focus_out;
 	widget_class->draw = pluma_view_draw;
+	widget_class->scroll_event = pluma_view_scroll_event;
 	
 	/*
 	 * Override the gtk_text_view_drag_motion and drag_drop
@@ -646,33 +679,110 @@ pluma_view_scroll_to_cursor (PlumaView *view)
 				      0.0);
 }
 
-static void
-pluma_override_font (GtkWidget   *widget,
-		     const gchar *font)
+static PangoFontDescription* get_system_font (void)
 {
+	PangoFontDescription *desc = NULL;
+	GSettings *settings;
+	char *name;
+
+	settings = g_settings_new ("org.mate.interface");
+	name = g_settings_get_string (settings, "font-name");
+
+	if (name)
+	{
+		desc = pango_font_description_from_string (name);
+		g_free (name);
+	}
+
+	g_object_unref (settings);
+
+	return desc;
+}
+
+static void
+system_font_changed_cb (GSettings *settings,
+			gchar     *key,
+			gpointer   user_data)
+{
+	PangoFontDescription *sys_font_desc = NULL;
+	sys_font_desc = get_system_font ();
+	if (sys_font_desc)
+	{
+		pluma_override_font ("label", NULL, sys_font_desc);
+		pango_font_description_free (sys_font_desc);
+	}
+}
+
+void
+pluma_override_font (const gchar          *item,
+		     GtkWidget            *widget,
+		     PangoFontDescription *font)
+{
+	static gboolean provider_added = FALSE;
+	static GtkCssProvider *provider; /*We need to keep this as long as Pluma is running*/
+	gchar          *prov_str;
 	gchar          *css;
-	GtkCssProvider *provider;
-	gchar          *tempsize;
+	gchar          *family;
+	gchar          *weight;
+	const gchar    *style;
+	gchar          *size;
 
-	provider = gtk_css_provider_new ();
-	tempsize = g_strdup (font);
+	family = g_strdup_printf ("font-family: %s;", pango_font_description_get_family (font));
 
-	g_strreverse (tempsize);
-	g_strcanon (tempsize, "1234567890", '\0');
-	g_strreverse (tempsize);
+	weight = g_strdup_printf ("font-weight: %d;", pango_font_description_get_weight (font));
 
-	gchar tempfont [strlen (font)];
-	strcpy (tempfont, font);
-	tempfont [strlen (font) - strlen (tempsize)] = 0;
+	if (pango_font_description_get_style (font) == PANGO_STYLE_NORMAL)
+		style = "font-style: normal;";
+	else if (pango_font_description_get_style (font) == PANGO_STYLE_ITALIC)
+		style = "font-style: italic;";
+	else
+		style = "font-style: oblique;";
+
+	size = g_strdup_printf ("font-size: %d%s;",
+				pango_font_description_get_size (font) / PANGO_SCALE,
+				pango_font_description_get_size_is_absolute (font) ? "px" : "pt");
+
+	if (!provider_added)
+		provider = gtk_css_provider_new ();
+
+	prov_str = gtk_css_provider_to_string (provider);
+
+	if (g_str_has_prefix (prov_str, "textview") && g_str_has_prefix (item, "label"))
+	{
+		if (strstr (prov_str, "label"))
+		{
+			g_strdelimit (prov_str, "}", '\0');
+			gchar *prov_new_str = g_strdup_printf ("%s}", prov_str);
+			css = g_strdup_printf ("%s %s { %s %s %s %s }", prov_new_str, item, family, weight, style, size);
+			g_free (prov_new_str);
+		}
+		else
+			css = g_strdup_printf ("%s %s { %s %s %s %s }", prov_str, item, family, weight, style, size);
+	}
+	else
+		css = g_strdup_printf ("%s { %s %s %s %s }", item, family, weight, style, size);
 
-	css = g_strdup_printf ("textview { font-family: %s; font-size: %spt; }", tempfont, tempsize);
 	gtk_css_provider_load_from_data (provider, css, -1, NULL);
-	g_free (css);
 
-	gtk_style_context_add_provider (gtk_widget_get_style_context (widget),
-					GTK_STYLE_PROVIDER (provider),
-					GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
-	g_object_unref (provider);
+	if (!provider_added)
+	{
+		static GSettings *settings; /*We need this for the life of the provider and program*/
+		settings = g_settings_new ("org.mate.interface");
+		g_signal_connect (settings,
+				  "changed::" "font-name",
+				  G_CALLBACK (system_font_changed_cb), NULL);
+
+		gtk_style_context_add_provider_for_screen (gtk_widget_get_screen (widget),
+							   GTK_STYLE_PROVIDER (provider),
+							   GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+		provider_added = TRUE;
+	}
+
+	g_free (css);
+	g_free (family);
+	g_free (weight);
+	g_free (size);
+	g_free (prov_str);
 }
 
 /* FIXME this is an issue for introspection */
@@ -691,6 +801,7 @@ pluma_view_set_font (PlumaView   *view,
 		     const gchar *font_name)
 {
 	PangoFontDescription *font_desc = NULL;
+	PangoFontDescription *sys_font_desc = NULL;
 
 	pluma_debug (DEBUG_VIEW);
 
@@ -713,7 +824,13 @@ pluma_view_set_font (PlumaView   *view,
 
 	g_return_if_fail (font_desc != NULL);
 
-	pluma_override_font (GTK_WIDGET (view), pango_font_description_to_string (font_desc));
+	pluma_override_font ("textview", GTK_WIDGET (view), font_desc);
+
+	sys_font_desc = get_system_font ();
+	if (sys_font_desc) {
+		pluma_override_font ("label", GTK_WIDGET (view), sys_font_desc);
+		pango_font_description_free (sys_font_desc);
+	}
 
 	pango_font_description_free (font_desc);		
 }
@@ -2020,6 +2137,18 @@ show_line_numbers_menu (GtkWidget      *view,
 static gboolean
 pluma_view_button_press_event (GtkWidget *widget, GdkEventButton *event)
 {
+	static gchar  *primtxt = "";
+
+	gchar *txt_clip = gtk_clipboard_wait_for_text (gtk_clipboard_get (GDK_SELECTION_PRIMARY));
+
+	if (txt_clip)
+	{
+		primtxt = g_strdup (txt_clip);
+		g_free (txt_clip);
+	}
+	else
+		gtk_clipboard_set_text (gtk_clipboard_get (GDK_SELECTION_PRIMARY), primtxt, strlen (primtxt));
+
 	if ((event->type == GDK_BUTTON_PRESS) && 
 	    (event->window == gtk_text_view_get_window (GTK_TEXT_VIEW (widget),
 						        GTK_TEXT_WINDOW_LEFT)))
